MinecraftEntityId

Struct MinecraftEntityId 

pub struct MinecraftEntityId(pub i32);
An entity ID used by Minecraft.

These IDs are picked by the server. Some server software (like Bungeecord) may pick entity IDs per-player, so you should avoid relying on them for identifying IDs (especially if you’re using a shared world – i.e. a swarm).

You might find Entity more useful, since that’s an ID decided by us that is likely to be correct across shared worlds. You could also use the EntityUuid from azalea_entity, that one is unlikely to change even across server restarts.

This serializes as a i32. Usually it’s a VarInt in the protocol, but not always. If you do need it to serialize as a VarInt, make sure to use use the #[var] attribute.

Tuple Fields

0: i32

Methods from Deref<Target = i32>

1.43.0 · Source

pub const MIN: i32

1.43.0 · Source

pub const MAX: i32

1.53.0 · Source

pub const BITS: u32 = u32::BITS